@@ -1,5 +1,7 @@
 """Built in actions for Jaseci"""
+from jaseci import JsOrc
 from jaseci.actions.live_actions import jaseci_action
+from jaseci.svc.task_svc import TaskService
 
 
 @jaseci_action()
@@ -7,9 +9,5 @@ def get_result(task_id, wait, meta):
     """
     Get task result by task_id
     """
-    task = meta["h"].task
 
-    if not task.is_running():
-        raise Exception("Task hook is not yet initialized!")
-
-    return task.get_by_task_id(task_id, wait)
+    return JsOrc.svc("task").poke(TaskService).get_by_task_id(task_id, wait)
