@@ -13,5 +13,13 @@ def get_page_meta(url: str = ""):
     if url == "":
         raise HTTPException(status_code=400, detail=str("No url provided"))
 
-    page = metadata_parser.MetadataParser(url=url)
-    return page.metadata
+    try:
+        page = metadata_parser.MetadataParser(
+            url=url,
+            url_headers={
+                "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:94.0) Gecko/20100101 Firefox/94.0",
+            },
+        )
+        return page.metadata
+    except Exception as e:
+        raise HTTPException(status_code=500, detail=str(e))
