@@ -2,6 +2,8 @@
 Queue api functions as a mixin
 """
 from jaseci.api.interface import Interface
+from jaseci import JsOrc
+from jaseci.svc.task_svc import TaskService
 
 
 class QueueApi:
@@ -16,23 +18,25 @@ class QueueApi:
         """
         Monitor Queues
         """
-        if not self._h.task.is_running():
+        task = JsOrc.svc("task", TaskService)
+        if not task.is_running():
             return "Task hook is not yet initialized!"
 
         if not task_id:
-            return self._h.task.inspect_tasks()
+            return task.inspect_tasks()
         else:
-            return self._h.task.get_by_task_id(task_id)
+            return task.get_by_task_id(task_id)
 
     @Interface.private_api(allowed_methods=["get"])
     def walker_queue_wait(self, task_id: str, timeout: int = 30):
         """
         Wait Queues
         """
-        if not self._h.task.is_running():
+        task = JsOrc.svc("task", TaskService)
+        if not task.is_running():
             return "Task hook is not yet initialized!"
 
         if not task_id:
             return "Task id is required!"
         else:
-            return self._h.task.get_by_task_id(task_id, True, timeout)
+            return task.get_by_task_id(task_id, True, timeout)
