@@ -6,7 +6,7 @@ from jaseci.actor.sentinel import Sentinel
 from jaseci.element.element import Element
 from jaseci.graph.graph import Graph
 from jaseci.graph.node import Node
-from jaseci.svc import MetaService
+from jaseci import JsOrc
 from jaseci.utils.utils import TestCaseHelper, get_all_subclasses
 from jaseci.actor.architype import Architype
 
@@ -14,14 +14,13 @@ from jaseci.actor.architype import Architype
 class ArchitypeTests(TestCaseHelper, TestCase):
     def setUp(self):
         super().setUp()
-        self.meta = MetaService(run_svcs=False)
 
     def tearDown(self):
         super().tearDown()
 
     def test_object_creation_basic_no_side_creation(self):
         """ """
-        mast = self.meta.build_master()
+        mast = JsOrc.master()
         num_objs = len(mast._h.mem.keys())
         node1 = Node(m_id=mast._m_id, h=mast._h)
         node2 = Node(m_id=mast._m_id, h=mast._h, parent=node1)
@@ -40,7 +39,7 @@ class ArchitypeTests(TestCaseHelper, TestCase):
 
     def test_edge_removal_updates_nodes_edgelist(self):
         """ """
-        mast = self.meta.build_master()
+        mast = JsOrc.master()
         node1 = Node(m_id=mast._m_id, h=mast._h)
         node2 = Node(m_id=mast._m_id, h=mast._h)
         edge = node1.attach_outbound(node2)
@@ -55,7 +54,7 @@ class ArchitypeTests(TestCaseHelper, TestCase):
         """
         Test that the destroy of sentinels clears owned objects
         """
-        mast = self.meta.build_master()
+        mast = JsOrc.master()
         num_objs = len(mast._h.mem.keys())
         self.assertEqual(num_objs, 2)
         new_graph = Graph(m_id=mast._m_id, h=mast._h)
@@ -77,7 +76,7 @@ class ArchitypeTests(TestCaseHelper, TestCase):
         Test saving object to json and back to python dict
         """
         for i in get_all_subclasses(Element):
-            kwargs = {"m_id": 0, "h": self.meta.build_hook()}
+            kwargs = {"m_id": 0, "h": JsOrc.hook()}
             orig = i(**kwargs)
             blob1 = orig.json(detailed=True)
             new = i(**kwargs)
@@ -87,11 +86,11 @@ class ArchitypeTests(TestCaseHelper, TestCase):
             self.assertTrue(orig.is_equivalent(new))
 
     def test_supermaster_can_touch_all_data(self):
-        mh = self.meta.build_hook()
-        mast = self.meta.build_master(h=mh)
-        mast2 = self.meta.build_master(h=mh)
+        mh = JsOrc.hook()
+        mast = JsOrc.master(h=mh)
+        mast2 = JsOrc.master(h=mh)
         node12 = Node(m_id=mast2._m_id, h=mast2._h)
-        supmast = self.meta.build_super_master(h=mh)
+        supmast = JsOrc.super_master(h=mh)
         bad = mh.get_obj(mast._m_id, node12.jid)
         good = mh.get_obj(supmast._m_id, node12.jid)
         self.assertEqual(good, node12)
@@ -100,13 +99,13 @@ class ArchitypeTests(TestCaseHelper, TestCase):
 
     def test_id_list_smart_name_error(self):
         self.logger_on()
-        mast = self.meta.build_master()
+        mast = JsOrc.master()
         sent = Sentinel(m_id=mast._m_id, h=mast._h)
         self.assertIn("arch_ids", sent.arch_ids.obj_for_id_not_exist_error(0))
 
     def test_dont_store_invalid_feilds_in_blob(self):
         self.logger_on()
-        mast = self.meta.build_master()
+        mast = JsOrc.master()
         sent = Sentinel(m_id=mast._m_id, h=mast._h)
         sent.fake_data = 5
         stored = sent.jsci_payload()
@@ -115,7 +114,7 @@ class ArchitypeTests(TestCaseHelper, TestCase):
         self.assertNotIn("fake_data", vars(sent2).keys())
 
     def test_sentinel_default_archs_dont_grow(self):
-        mast = self.meta.build_master()
+        mast = JsOrc.master()
         sent = Sentinel(m_id=mast._m_id, h=mast._h)
         sent.register_code(text="node simple; walker init {}")
         before = sent._h.get_object_distribution()[Architype]
@@ -128,7 +127,7 @@ class ArchitypeTests(TestCaseHelper, TestCase):
         self.assertEqual(before, after)
 
     def test_sentinel_default_archs_dont_grow_multi_compile(self):
-        mast = self.meta.build_master()
+        mast = JsOrc.master()
         sent = Sentinel(m_id=mast._m_id, h=mast._h)
         sent.register_code(text="node simple; walker init {}")
         before = sent._h.get_object_distribution()[Architype]
@@ -145,7 +144,7 @@ class ArchitypeTests(TestCaseHelper, TestCase):
         self.assertNotEqual(before_id, after_id)
 
     def test_id_list_heals(self):
-        mast = self.meta.build_master()
+        mast = JsOrc.master()
         sent = Sentinel(m_id=mast._m_id, h=mast._h)
         sent.register_code(text="node simple; walker init {}")
         before = len(sent.arch_ids)
